@@ -3,6 +3,8 @@ require 'date'
 
 module Shoulda
   module Matchers
+    class ExampleClass; end
+
     module ActiveModel
       # The `validate_inclusion_of` matcher tests usage of the
       # `validates_inclusion_of` validation, asserting that an attribute can
@@ -43,12 +45,12 @@ module Shoulda
       #
       #     # RSpec
       #     RSpec.describe Issue, type: :model do
-      #       it { should validate_inclusion_of(:state).in_range(1..5) }
+      #       it { should validate_inclusion_of(:priority).in_range(1..5) }
       #     end
       #
       #     # Minitest (Shoulda)
       #     class IssueTest < ActiveSupport::TestCase
-      #       should validate_inclusion_of(:state).in_range(1..5)
+      #       should validate_inclusion_of(:priority).in_range(1..5)
       #     end
       #
       # #### Caveats
@@ -269,7 +271,7 @@ module Shoulda
       # @private
       class ValidateInclusionOfMatcher < ValidationMatcher
         BLANK_VALUES = ['', ' ', "\n", "\r", "\t", "\f"].freeze
-        ARBITRARY_OUTSIDE_STRING = 'shoulda-matchers test string'.freeze
+        ARBITRARY_OUTSIDE_STRING = Shoulda::Matchers::ExampleClass.name
         ARBITRARY_OUTSIDE_INTEGER = 123456789
         ARBITRARY_OUTSIDE_DECIMAL = BigDecimal('0.123456789')
         ARBITRARY_OUTSIDE_DATE = Date.jd(9999999)
@@ -355,7 +357,7 @@ EOT
             description = "validate that :#{@attribute}"
 
             description <<
-              if @array.many?
+              if @array.count > 1
                 " is either #{inspected_array}"
               else
                 " is #{inspected_array}"
