@@ -11,16 +11,8 @@ module UnitTests
       Tests::Version.new(Rails::VERSION::STRING)
     end
 
-    def rails_lt_5?
-      rails_version < 5
-    end
-
-    def rails_5_x?
-      rails_version =~ '~> 5.0'
-    end
-
-    def rails_gte_5_2?
-      rails_version >= 5.2
+    def rails_oldest_version_supported
+      5.2
     end
   end
 end
