@@ -21,7 +21,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :integer, value: 1),
+          **options.merge(column_type: :integer, value: 1),
           &block
         )
       end
@@ -45,7 +45,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(
+          **options.merge(
             column_type: :integer,
             column_options: { limit: 2 },
             value: 1,
@@ -71,7 +71,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :float, value: 1.0),
+          **options.merge(column_type: :float, value: 1.0),
           &block
         )
       end
@@ -99,7 +99,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :decimal, value: BigDecimal('1.0')),
+          **options.merge(column_type: :decimal, value: BigDecimal('1.0')),
           &block
         )
       end
@@ -130,7 +130,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :date, value: today),
+          **options.merge(column_type: :date, value: today),
           &block
         )
       end
@@ -145,7 +145,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     end
 
     context 'against a datetime attribute' do
-      now = DateTime.now
+      now = DateTime.new(2022, 1, 1)
 
       define_method(:now) { now }
 
@@ -158,7 +158,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :datetime, value: now),
+          **options.merge(column_type: :datetime, value: now),
           &block
         )
       end
@@ -186,7 +186,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :time, value: default_time),
+          **options.merge(column_type: :time, value: default_time),
           &block
         )
       end
@@ -207,7 +207,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :string),
+          **options.merge(column_type: :string),
           &block
         )
       end
@@ -454,7 +454,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
     it 'matches given a subset of the valid values' do
       builder = build_object_allowing(possible_values)
-      expect_to_match_on_values(builder, possible_values[1..-1])
+      expect_to_match_on_values(builder, possible_values[1..])
     end
 
     if zero
@@ -785,8 +785,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     include_context 'for a generic attribute'
 
     context 'against a timestamp column' do
-      now = DateTime.now
-
+      now = DateTime.new(2022, 1, 1)
       define_method(:now) { now }
 
       it_behaves_like 'it supports in_array',
@@ -798,7 +797,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
       define_method :build_object do |options = {}, &block|
         build_object_with_generic_attribute(
-          options.merge(column_type: :timestamp, value: now),
+          **options.merge(column_type: :timestamp, value: now),
           &block
         )
       end
@@ -842,7 +841,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
 
         def build_object(**options, &block)
           super(
-            options.merge(column_options: { null: true }, value: true),
+            **options.merge(column_options: { null: true }, value: true),
             &block
           )
         end
@@ -863,13 +862,13 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
         end
 
         def build_object(**options, &block)
-          super(options.merge(column_options: { null: false }), &block)
+          super(**options.merge(column_options: { null: false }), &block)
         end
       end
 
       def build_object(**options, &block)
         build_object_with_generic_attribute(
-          options.merge(column_type: :boolean),
+          **options.merge(column_type: :boolean),
           &block
         )
       end
@@ -887,6 +886,41 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
     def validation_matcher_scenario_args
       super.deep_merge(model_creator: :active_record)
     end
+
+    context 'against a polymorphic association' do
+      it 'matches when the subject configures validate_inclusion_of' do
+        define_model(:issue, severity_id: :integer, severity_type: :string) do
+          belongs_to :severity, polymorphic: true
+          validates_inclusion_of :severity_type, in: %w(Low Medium High)
+        end
+        define_model(:high)
+        define_model(:medium)
+        define_model(:low)
+
+        expect { validate_inclusion_of(:severity_type).in_array(%w(Low Medium High)) }.to match_against(Issue.new)
+      end
+
+      it 'does not match when subject does not set validate_inclusion_of' do
+        define_model(:issue, severity_id: :integer, severity_type: :string) do
+          belongs_to :severity, polymorphic: true
+        end
+        define_model(:high)
+        define_model(:medium)
+        define_model(:low)
+
+        expected_message = <<-MESSAGE.strip
+Expected Issue to validate that :severity_type is either ‹"Low"›,
+‹"Medium"›, or ‹"High"›, but this could not be proved.
+  After setting :severity_type to ‹"Shoulda::Matchers::ExampleClass"›,
+  the matcher expected the Issue to be invalid, but it was valid
+  instead.
+        MESSAGE
+
+        expect { validate_inclusion_of(:severity_type).in_array(%w(Low Medium High)) }.
+          not_to match_against(Issue.new).
+          and_fail_with(expected_message)
+      end
+    end
   end
 
   context 'for a plain Ruby attribute' do
@@ -896,7 +930,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       include_context 'against a boolean attribute for true and false'
 
       def build_object(**options, &block)
-        build_object_with_generic_attribute(options.merge(value: true), &block)
+        build_object_with_generic_attribute(**options.merge(value: true), &block)
       end
     end
 
@@ -904,7 +938,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       include_context 'against a boolean attribute for true and false'
 
       def build_object(**options, &block)
-        build_object_with_generic_attribute(options.merge(value: false), &block)
+        build_object_with_generic_attribute(**options.merge(value: false), &block)
       end
     end
 
@@ -1010,7 +1044,7 @@ describe Shoulda::Matchers::ActiveModel::ValidateInclusionOfMatcher, type: :mode
       column_options: column_options,
     }.compact
 
-    define_simple_model(model_options) do |model|
+    define_simple_model(**model_options) do |model|
       if validation_options
         model.validates_inclusion_of(attribute_name, validation_options)
       end
