@@ -69,26 +69,34 @@ describe Shoulda::Matchers::ActiveModel::ValidateNumericalityOfMatcher, type: :m
           validation_name: :on,
           validation_value: :customizable,
         },
+        {
+          category: :range,
+          name: :is_in,
+          argument: 1..10,
+          validation_name: :in,
+          validation_value: 1..10,
+          rails_version: 7.0,
+        },
       ]
     end
 
     def qualifiers_under(category)
-      all_qualifiers.select do |qualifier|
+      all_available_qualifiers.select do |qualifier|
         qualifier[:category] == category
       end
     end
 
     def mutually_exclusive_qualifiers
-      qualifiers_under(:cardinality) + qualifiers_under(:comparison)
+      qualifiers_under(:cardinality) + qualifiers_under(:comparison) + qualifiers_under(:range)
     end
 
     def non_mutually_exclusive_qualifiers
-      all_qualifiers - mutually_exclusive_qualifiers
+      all_available_qualifiers - mutually_exclusive_qualifiers
     end
 
-    def validations_by_qualifier
-      all_qualifiers.each_with_object({}) do |qualifier, hash|
-        hash[qualifier[:name]] = qualifier[:validation_name]
+    def all_available_qualifiers
+      all_qualifiers.filter do |qualifier|
+        rails_version >= qualifier.fetch(:rails_version, rails_oldest_version_supported)
       end
     end
 
@@ -2065,6 +2073,144 @@ could not be proved.
     end
   end
 
+  if rails_version >= 7.0
+    context 'qualified with in' do
+      context 'validating with in' do
+        it 'accepts' do
+          record = build_record_validating_numericality(
+            in: 1..10,
+          )
+          expect(record).to validate_numericality.is_in(1..10)
+        end
+
+        it 'rejects when used in the negative' do
+          record = build_record_validating_numericality(
+            in: 1..10,
+          )
+
+          assertion = lambda do
+            expect(record).not_to validate_numericality.is_in(1..10)
+          end
+
+          expect(&assertion).to fail_with_message(<<~MESSAGE)
+  Expected Example not to validate that :attr looks like a number from ‹1›
+  to ‹10›, but this could not be proved.
+    After setting :attr to ‹"abcd"›, the matcher expected the Example to
+    be valid, but it was invalid instead, producing these validation
+    errors:
+
+    * attr: ["is not a number"]
+          MESSAGE
+        end
+
+        it_supports(
+          'ignoring_interference_by_writer',
+          tests: {
+            reject_if_qualified_but_changing_value_interferes: {
+              model_name: 'Example',
+              attribute_name: :attr,
+              changing_values_with: :next_value,
+              expected_message: <<-MESSAGE.strip,
+Expected Example to validate that :attr looks like a number from ‹1› to
+‹10›, but this could not be proved.
+  After setting :attr to ‹"10"› -- which was read back as ‹"11"› -- the
+  matcher expected the Example to be valid, but it was invalid instead,
+  producing these validation errors:
+
+  * attr: ["must be in 1..10"]
+
+  As indicated in the message above, :attr seems to be changing certain
+  values as they are set, and this could have something to do with why
+  this test is failing. If you've overridden the writer method for this
+  attribute, then you may need to change it to make this test pass, or
+  do something else entirely.
+              MESSAGE
+            },
+          },
+        ) do
+          def validation_matcher_scenario_args
+            super.deep_merge(
+              validation_options: { in: 1..10 },
+            )
+          end
+
+          def configure_validation_matcher(matcher)
+            matcher.is_in(1..10)
+          end
+        end
+
+        context 'when the attribute is a virtual attribute in an ActiveRecord model' do
+          it 'accepts' do
+            record = build_record_validating_numericality_of_virtual_attribute(
+              in: 1..10,
+            )
+            expect(record).to validate_numericality.
+              is_in(1..10)
+          end
+        end
+
+        context 'when the column is an integer column' do
+          it 'accepts (and does not raise an error)' do
+            record = build_record_validating_numericality(
+              column_type: :integer,
+              in: 1..10,
+            )
+
+            expect(record).
+              to validate_numericality.
+              is_in(1..10)
+          end
+        end
+
+        context 'when the column is a float column' do
+          it 'accepts (and does not raise an error)' do
+            record = build_record_validating_numericality(
+              column_type: :float,
+              in: 1..10,
+            )
+
+            expect(record).
+              to validate_numericality.
+              is_in(1..10)
+          end
+        end
+
+        context 'when the column is a decimal column' do
+          it 'accepts (and does not raise an error)' do
+            record = build_record_validating_numericality(
+              column_type: :decimal,
+              in: 1..10,
+            )
+
+            expect(record).
+              to validate_numericality.
+              is_in(1..10)
+          end
+        end
+      end
+
+      context 'not validating with in' do
+        it 'rejects since it does not disallow numbers that are not in the range specified' do
+          record = build_record_validating_numericality
+
+          assertion = lambda do
+            expect(record).to validate_numericality.
+              is_in(1..10)
+          end
+
+          message = <<-MESSAGE
+Expected Example to validate that :attr looks like a number from ‹1› to
+‹10›, but this could not be proved.
+  After setting :attr to ‹"11"›, the matcher expected the Example to be
+  invalid, but it was valid instead.
+          MESSAGE
+
+          expect(&assertion).to fail_with_message(message)
+        end
+      end
+    end
+  end
+
   def build_validation_options(args)
     combination = args.fetch(:for)
 
@@ -2080,7 +2226,11 @@ could not be proved.
 
     combination.each do |qualifier|
       args = self.class.default_qualifier_arguments.fetch(qualifier[:name])
-      matcher.__send__(qualifier[:name], *args)
+      if args
+        matcher.__send__(qualifier[:name], args)
+      else
+        matcher.__send__(qualifier[:name])
+      end
     end
   end
 
